pub trait AsExpression<T>where
T: SqlType + TypedExpressionType,{
type Expression: Expression<SqlType = T>;
// Required method
fn as_expression(self) -> Self::Expression;
}Expand description
Converts a type to its representation for use in Diesel’s query builder.
This trait is used directly. Apps should typically use IntoSql instead.
Implementations of this trait will generally do one of 3 things:
-
Return
selffor types which are already parts of Diesel’s query builder -
Perform some implicit coercion (for example, allowing
nowto be used as bothTimestampandTimestamptz. -
Indicate that the type has data which will be sent separately from the query. This is generally referred as a “bind parameter”. Types which implement
ToSqlwill generally implementAsExpressionthis way.
This trait could be derived
Required Associated Types
Sourcetype Expression: Expression<SqlType = T>
type Expression: Expression<SqlType = T>
The expression being returned
Required Methods
Sourcefn as_expression(self) -> Self::Expression
fn as_expression(self) -> Self::Expression
Perform the conversion
Implementations on Foreign Types
Sourceimpl AsExpression<BigInt> for i64
impl AsExpression<BigInt> for i64
type Expression = Bound<BigInt, i64>
fn as_expression(self) -> <Self as AsExpression<BigInt>>::Expression
Sourceimpl AsExpression<Binary> for Vec<u8>
impl AsExpression<Binary> for Vec<u8>
type Expression = Bound<Binary, Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl AsExpression<Bool> for bool
impl AsExpression<Bool> for bool
type Expression = Bound<Bool, bool>
fn as_expression(self) -> <Self as AsExpression<Bool>>::Expression
Sourceimpl AsExpression<Date> for String
impl AsExpression<Date> for String
type Expression = Bound<Date, String>
fn as_expression(self) -> <Self as AsExpression<Date>>::Expression
Sourceimpl AsExpression<Double> for f64
impl AsExpression<Double> for f64
type Expression = Bound<Double, f64>
fn as_expression(self) -> <Self as AsExpression<Double>>::Expression
Sourceimpl AsExpression<Float> for f32
impl AsExpression<Float> for f32
type Expression = Bound<Float, f32>
fn as_expression(self) -> <Self as AsExpression<Float>>::Expression
Sourceimpl AsExpression<Integer> for i32
impl AsExpression<Integer> for i32
type Expression = Bound<Integer, i32>
fn as_expression(self) -> <Self as AsExpression<Integer>>::Expression
Sourceimpl AsExpression<Nullable<BigInt>> for i64
impl AsExpression<Nullable<BigInt>> for i64
type Expression = Bound<Nullable<BigInt>, i64>
fn as_expression(self) -> <Self as AsExpression<Nullable<BigInt>>>::Expression
Sourceimpl AsExpression<Nullable<Binary>> for Vec<u8>
impl AsExpression<Nullable<Binary>> for Vec<u8>
type Expression = Bound<Nullable<Binary>, Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl AsExpression<Nullable<Bool>> for bool
impl AsExpression<Nullable<Bool>> for bool
type Expression = Bound<Nullable<Bool>, bool>
fn as_expression(self) -> <Self as AsExpression<Nullable<Bool>>>::Expression
Sourceimpl AsExpression<Nullable<Date>> for String
impl AsExpression<Nullable<Date>> for String
type Expression = Bound<Nullable<Date>, String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Date>>>::Expression
Sourceimpl AsExpression<Nullable<Double>> for f64
impl AsExpression<Nullable<Double>> for f64
type Expression = Bound<Nullable<Double>, f64>
fn as_expression(self) -> <Self as AsExpression<Nullable<Double>>>::Expression
Sourceimpl AsExpression<Nullable<Float>> for f32
impl AsExpression<Nullable<Float>> for f32
type Expression = Bound<Nullable<Float>, f32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Float>>>::Expression
Sourceimpl AsExpression<Nullable<Integer>> for i32
impl AsExpression<Nullable<Integer>> for i32
type Expression = Bound<Nullable<Integer>, i32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Integer>>>::Expression
Sourceimpl AsExpression<Nullable<SmallInt>> for i16
impl AsExpression<Nullable<SmallInt>> for i16
type Expression = Bound<Nullable<SmallInt>, i16>
fn as_expression(self) -> <Self as AsExpression<Nullable<SmallInt>>>::Expression
Sourceimpl AsExpression<Nullable<Text>> for String
impl AsExpression<Nullable<Text>> for String
type Expression = Bound<Nullable<Text>, String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Text>>>::Expression
Sourceimpl AsExpression<Nullable<Time>> for String
impl AsExpression<Nullable<Time>> for String
type Expression = Bound<Nullable<Time>, String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Time>>>::Expression
Sourceimpl AsExpression<Nullable<Timestamp>> for String
impl AsExpression<Nullable<Timestamp>> for String
type Expression = Bound<Nullable<Timestamp>, String>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl AsExpression<Nullable<Timestamp>> for SystemTime
impl AsExpression<Nullable<Timestamp>> for SystemTime
type Expression = Bound<Nullable<Timestamp>, SystemTime>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl AsExpression<SmallInt> for i16
impl AsExpression<SmallInt> for i16
type Expression = Bound<SmallInt, i16>
fn as_expression(self) -> <Self as AsExpression<SmallInt>>::Expression
Sourceimpl AsExpression<Text> for String
impl AsExpression<Text> for String
type Expression = Bound<Text, String>
fn as_expression(self) -> <Self as AsExpression<Text>>::Expression
Sourceimpl AsExpression<Time> for String
impl AsExpression<Time> for String
type Expression = Bound<Time, String>
fn as_expression(self) -> <Self as AsExpression<Time>>::Expression
Sourceimpl AsExpression<Timestamp> for String
impl AsExpression<Timestamp> for String
type Expression = Bound<Timestamp, String>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl AsExpression<Timestamp> for SystemTime
impl AsExpression<Timestamp> for SystemTime
type Expression = Bound<Timestamp, SystemTime>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr> AsExpression<BigInt> for &'__expr i64
impl<'__expr> AsExpression<BigInt> for &'__expr i64
type Expression = Bound<BigInt, &'__expr i64>
fn as_expression(self) -> <Self as AsExpression<BigInt>>::Expression
Sourceimpl<'__expr> AsExpression<Binary> for &'__expr Vec<u8>
impl<'__expr> AsExpression<Binary> for &'__expr Vec<u8>
type Expression = Bound<Binary, &'__expr Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr> AsExpression<Binary> for &'__expr [u8]
impl<'__expr> AsExpression<Binary> for &'__expr [u8]
type Expression = Bound<Binary, &'__expr [u8]>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr> AsExpression<Bool> for &'__expr bool
impl<'__expr> AsExpression<Bool> for &'__expr bool
type Expression = Bound<Bool, &'__expr bool>
fn as_expression(self) -> <Self as AsExpression<Bool>>::Expression
Sourceimpl<'__expr> AsExpression<Date> for &'__expr str
impl<'__expr> AsExpression<Date> for &'__expr str
type Expression = Bound<Date, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Date>>::Expression
Sourceimpl<'__expr> AsExpression<Date> for &'__expr String
impl<'__expr> AsExpression<Date> for &'__expr String
type Expression = Bound<Date, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Date>>::Expression
Sourceimpl<'__expr> AsExpression<Double> for &'__expr f64
impl<'__expr> AsExpression<Double> for &'__expr f64
type Expression = Bound<Double, &'__expr f64>
fn as_expression(self) -> <Self as AsExpression<Double>>::Expression
Sourceimpl<'__expr> AsExpression<Float> for &'__expr f32
impl<'__expr> AsExpression<Float> for &'__expr f32
type Expression = Bound<Float, &'__expr f32>
fn as_expression(self) -> <Self as AsExpression<Float>>::Expression
Sourceimpl<'__expr> AsExpression<Integer> for &'__expr i32
impl<'__expr> AsExpression<Integer> for &'__expr i32
type Expression = Bound<Integer, &'__expr i32>
fn as_expression(self) -> <Self as AsExpression<Integer>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<BigInt>> for &'__expr i64
impl<'__expr> AsExpression<Nullable<BigInt>> for &'__expr i64
type Expression = Bound<Nullable<BigInt>, &'__expr i64>
fn as_expression(self) -> <Self as AsExpression<Nullable<BigInt>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Binary>> for &'__expr Vec<u8>
impl<'__expr> AsExpression<Nullable<Binary>> for &'__expr Vec<u8>
type Expression = Bound<Nullable<Binary>, &'__expr Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Binary>> for &'__expr [u8]
impl<'__expr> AsExpression<Nullable<Binary>> for &'__expr [u8]
type Expression = Bound<Nullable<Binary>, &'__expr [u8]>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Bool>> for &'__expr bool
impl<'__expr> AsExpression<Nullable<Bool>> for &'__expr bool
type Expression = Bound<Nullable<Bool>, &'__expr bool>
fn as_expression(self) -> <Self as AsExpression<Nullable<Bool>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Date>> for &'__expr str
impl<'__expr> AsExpression<Nullable<Date>> for &'__expr str
type Expression = Bound<Nullable<Date>, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Date>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Date>> for &'__expr String
impl<'__expr> AsExpression<Nullable<Date>> for &'__expr String
type Expression = Bound<Nullable<Date>, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Date>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Double>> for &'__expr f64
impl<'__expr> AsExpression<Nullable<Double>> for &'__expr f64
type Expression = Bound<Nullable<Double>, &'__expr f64>
fn as_expression(self) -> <Self as AsExpression<Nullable<Double>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Float>> for &'__expr f32
impl<'__expr> AsExpression<Nullable<Float>> for &'__expr f32
type Expression = Bound<Nullable<Float>, &'__expr f32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Float>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Integer>> for &'__expr i32
impl<'__expr> AsExpression<Nullable<Integer>> for &'__expr i32
type Expression = Bound<Nullable<Integer>, &'__expr i32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Integer>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<SmallInt>> for &'__expr i16
impl<'__expr> AsExpression<Nullable<SmallInt>> for &'__expr i16
type Expression = Bound<Nullable<SmallInt>, &'__expr i16>
fn as_expression(self) -> <Self as AsExpression<Nullable<SmallInt>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Text>> for &'__expr str
impl<'__expr> AsExpression<Nullable<Text>> for &'__expr str
type Expression = Bound<Nullable<Text>, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Text>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Text>> for &'__expr String
impl<'__expr> AsExpression<Nullable<Text>> for &'__expr String
type Expression = Bound<Nullable<Text>, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Text>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Time>> for &'__expr str
impl<'__expr> AsExpression<Nullable<Time>> for &'__expr str
type Expression = Bound<Nullable<Time>, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Time>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Time>> for &'__expr String
impl<'__expr> AsExpression<Nullable<Time>> for &'__expr String
type Expression = Bound<Nullable<Time>, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Time>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr str
impl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr str
type Expression = Bound<Nullable<Timestamp>, &'__expr str>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr String
impl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr String
type Expression = Bound<Nullable<Timestamp>, &'__expr String>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr SystemTime
impl<'__expr> AsExpression<Nullable<Timestamp>> for &'__expr SystemTime
type Expression = Bound<Nullable<Timestamp>, &'__expr SystemTime>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr> AsExpression<SmallInt> for &'__expr i16
impl<'__expr> AsExpression<SmallInt> for &'__expr i16
type Expression = Bound<SmallInt, &'__expr i16>
fn as_expression(self) -> <Self as AsExpression<SmallInt>>::Expression
Sourceimpl<'__expr> AsExpression<Text> for &'__expr str
impl<'__expr> AsExpression<Text> for &'__expr str
type Expression = Bound<Text, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Text>>::Expression
Sourceimpl<'__expr> AsExpression<Text> for &'__expr String
impl<'__expr> AsExpression<Text> for &'__expr String
type Expression = Bound<Text, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Text>>::Expression
Sourceimpl<'__expr> AsExpression<Time> for &'__expr str
impl<'__expr> AsExpression<Time> for &'__expr str
type Expression = Bound<Time, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Time>>::Expression
Sourceimpl<'__expr> AsExpression<Time> for &'__expr String
impl<'__expr> AsExpression<Time> for &'__expr String
type Expression = Bound<Time, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Time>>::Expression
Sourceimpl<'__expr> AsExpression<Timestamp> for &'__expr str
impl<'__expr> AsExpression<Timestamp> for &'__expr str
type Expression = Bound<Timestamp, &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr> AsExpression<Timestamp> for &'__expr String
impl<'__expr> AsExpression<Timestamp> for &'__expr String
type Expression = Bound<Timestamp, &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr> AsExpression<Timestamp> for &'__expr SystemTime
impl<'__expr> AsExpression<Timestamp> for &'__expr SystemTime
type Expression = Bound<Timestamp, &'__expr SystemTime>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<BigInt> for &'__expr2 &'__expr i64
impl<'__expr, '__expr2> AsExpression<BigInt> for &'__expr2 &'__expr i64
type Expression = Bound<BigInt, &'__expr2 &'__expr i64>
fn as_expression(self) -> <Self as AsExpression<BigInt>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Binary> for &'__expr2 &'__expr Vec<u8>
impl<'__expr, '__expr2> AsExpression<Binary> for &'__expr2 &'__expr Vec<u8>
type Expression = Bound<Binary, &'__expr2 &'__expr Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Binary> for &'__expr2 &'__expr [u8]
impl<'__expr, '__expr2> AsExpression<Binary> for &'__expr2 &'__expr [u8]
type Expression = Bound<Binary, &'__expr2 &'__expr [u8]>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Bool> for &'__expr2 &'__expr bool
impl<'__expr, '__expr2> AsExpression<Bool> for &'__expr2 &'__expr bool
type Expression = Bound<Bool, &'__expr2 &'__expr bool>
fn as_expression(self) -> <Self as AsExpression<Bool>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Date> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Date> for &'__expr2 &'__expr str
type Expression = Bound<Date, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Date>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Date> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Date> for &'__expr2 &'__expr String
type Expression = Bound<Date, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Date>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Double> for &'__expr2 &'__expr f64
impl<'__expr, '__expr2> AsExpression<Double> for &'__expr2 &'__expr f64
type Expression = Bound<Double, &'__expr2 &'__expr f64>
fn as_expression(self) -> <Self as AsExpression<Double>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Float> for &'__expr2 &'__expr f32
impl<'__expr, '__expr2> AsExpression<Float> for &'__expr2 &'__expr f32
type Expression = Bound<Float, &'__expr2 &'__expr f32>
fn as_expression(self) -> <Self as AsExpression<Float>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Integer> for &'__expr2 &'__expr i32
impl<'__expr, '__expr2> AsExpression<Integer> for &'__expr2 &'__expr i32
type Expression = Bound<Integer, &'__expr2 &'__expr i32>
fn as_expression(self) -> <Self as AsExpression<Integer>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<BigInt>> for &'__expr2 &'__expr i64
impl<'__expr, '__expr2> AsExpression<Nullable<BigInt>> for &'__expr2 &'__expr i64
type Expression = Bound<Nullable<BigInt>, &'__expr2 &'__expr i64>
fn as_expression(self) -> <Self as AsExpression<Nullable<BigInt>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr Vec<u8>
impl<'__expr, '__expr2> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr Vec<u8>
type Expression = Bound<Nullable<Binary>, &'__expr2 &'__expr Vec<u8>>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr [u8]
impl<'__expr, '__expr2> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr [u8]
type Expression = Bound<Nullable<Binary>, &'__expr2 &'__expr [u8]>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Bool>> for &'__expr2 &'__expr bool
impl<'__expr, '__expr2> AsExpression<Nullable<Bool>> for &'__expr2 &'__expr bool
type Expression = Bound<Nullable<Bool>, &'__expr2 &'__expr bool>
fn as_expression(self) -> <Self as AsExpression<Nullable<Bool>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Date>> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Nullable<Date>> for &'__expr2 &'__expr str
type Expression = Bound<Nullable<Date>, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Date>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Date>> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Nullable<Date>> for &'__expr2 &'__expr String
type Expression = Bound<Nullable<Date>, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Date>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Double>> for &'__expr2 &'__expr f64
impl<'__expr, '__expr2> AsExpression<Nullable<Double>> for &'__expr2 &'__expr f64
type Expression = Bound<Nullable<Double>, &'__expr2 &'__expr f64>
fn as_expression(self) -> <Self as AsExpression<Nullable<Double>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Float>> for &'__expr2 &'__expr f32
impl<'__expr, '__expr2> AsExpression<Nullable<Float>> for &'__expr2 &'__expr f32
type Expression = Bound<Nullable<Float>, &'__expr2 &'__expr f32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Float>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Integer>> for &'__expr2 &'__expr i32
impl<'__expr, '__expr2> AsExpression<Nullable<Integer>> for &'__expr2 &'__expr i32
type Expression = Bound<Nullable<Integer>, &'__expr2 &'__expr i32>
fn as_expression(self) -> <Self as AsExpression<Nullable<Integer>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<SmallInt>> for &'__expr2 &'__expr i16
impl<'__expr, '__expr2> AsExpression<Nullable<SmallInt>> for &'__expr2 &'__expr i16
type Expression = Bound<Nullable<SmallInt>, &'__expr2 &'__expr i16>
fn as_expression(self) -> <Self as AsExpression<Nullable<SmallInt>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Text>> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Nullable<Text>> for &'__expr2 &'__expr str
type Expression = Bound<Nullable<Text>, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Text>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Text>> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Nullable<Text>> for &'__expr2 &'__expr String
type Expression = Bound<Nullable<Text>, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Text>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Time>> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Nullable<Time>> for &'__expr2 &'__expr str
type Expression = Bound<Nullable<Time>, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Nullable<Time>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Time>> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Nullable<Time>> for &'__expr2 &'__expr String
type Expression = Bound<Nullable<Time>, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Nullable<Time>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr str
type Expression = Bound<Nullable<Timestamp>, &'__expr2 &'__expr str>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr String
type Expression = Bound<Nullable<Timestamp>, &'__expr2 &'__expr String>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr SystemTime
impl<'__expr, '__expr2> AsExpression<Nullable<Timestamp>> for &'__expr2 &'__expr SystemTime
type Expression = Bound<Nullable<Timestamp>, &'__expr2 &'__expr SystemTime>
fn as_expression( self, ) -> <Self as AsExpression<Nullable<Timestamp>>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<SmallInt> for &'__expr2 &'__expr i16
impl<'__expr, '__expr2> AsExpression<SmallInt> for &'__expr2 &'__expr i16
type Expression = Bound<SmallInt, &'__expr2 &'__expr i16>
fn as_expression(self) -> <Self as AsExpression<SmallInt>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Text> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Text> for &'__expr2 &'__expr str
type Expression = Bound<Text, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Text>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Text> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Text> for &'__expr2 &'__expr String
type Expression = Bound<Text, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Text>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Time> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Time> for &'__expr2 &'__expr str
type Expression = Bound<Time, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Time>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Time> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Time> for &'__expr2 &'__expr String
type Expression = Bound<Time, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Time>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr str
impl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr str
type Expression = Bound<Timestamp, &'__expr2 &'__expr str>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr String
impl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr String
type Expression = Bound<Timestamp, &'__expr2 &'__expr String>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr SystemTime
impl<'__expr, '__expr2> AsExpression<Timestamp> for &'__expr2 &'__expr SystemTime
type Expression = Bound<Timestamp, &'__expr2 &'__expr SystemTime>
fn as_expression(self) -> <Self as AsExpression<Timestamp>>::Expression
Sourceimpl<'__expr, '__expr2, const N: usize> AsExpression<Binary> for &'__expr2 &'__expr [u8; N]
impl<'__expr, '__expr2, const N: usize> AsExpression<Binary> for &'__expr2 &'__expr [u8; N]
type Expression = Bound<Binary, &'__expr2 &'__expr [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr, '__expr2, const N: usize> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr [u8; N]
impl<'__expr, '__expr2, const N: usize> AsExpression<Nullable<Binary>> for &'__expr2 &'__expr [u8; N]
type Expression = Bound<Nullable<Binary>, &'__expr2 &'__expr [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'__expr, const N: usize> AsExpression<Binary> for &'__expr [u8; N]
impl<'__expr, const N: usize> AsExpression<Binary> for &'__expr [u8; N]
type Expression = Bound<Binary, &'__expr [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<'__expr, const N: usize> AsExpression<Nullable<Binary>> for &'__expr [u8; N]
impl<'__expr, const N: usize> AsExpression<Nullable<Binary>> for &'__expr [u8; N]
type Expression = Bound<Nullable<Binary>, &'__expr [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Sourceimpl<'a, 'b, T, ST> AsExpression<ST> for &'b Cow<'a, T>where
T: 'a + ToOwned + ?Sized,
Bound<ST, &'b T>: Expression<SqlType = ST>,
ST: SqlType + TypedExpressionType,
impl<'a, 'b, T, ST> AsExpression<ST> for &'b Cow<'a, T>where
T: 'a + ToOwned + ?Sized,
Bound<ST, &'b T>: Expression<SqlType = ST>,
ST: SqlType + TypedExpressionType,
type Expression = Bound<ST, &'b T>
fn as_expression(self) -> Self::Expression
Sourceimpl<'a, T, ST> AsExpression<ST> for Cow<'a, T>where
T: 'a + ToOwned + ?Sized,
Bound<ST, Cow<'a, T>>: Expression<SqlType = ST>,
ST: SqlType + TypedExpressionType,
impl<'a, T, ST> AsExpression<ST> for Cow<'a, T>where
T: 'a + ToOwned + ?Sized,
Bound<ST, Cow<'a, T>>: Expression<SqlType = ST>,
ST: SqlType + TypedExpressionType,
type Expression = Bound<ST, Cow<'a, T>>
fn as_expression(self) -> Self::Expression
Sourceimpl<T, ST> AsExpression<Nullable<ST>> for &Option<T>
impl<T, ST> AsExpression<Nullable<ST>> for &Option<T>
type Expression = Bound<Nullable<ST>, &Option<T>>
fn as_expression(self) -> Self::Expression
Sourceimpl<T, ST> AsExpression<Nullable<ST>> for Option<T>
impl<T, ST> AsExpression<Nullable<ST>> for Option<T>
type Expression = Bound<Nullable<ST>, Option<T>>
fn as_expression(self) -> Self::Expression
Sourceimpl<const N: usize> AsExpression<Binary> for [u8; N]
impl<const N: usize> AsExpression<Binary> for [u8; N]
type Expression = Bound<Binary, [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Binary>>::Expression
Sourceimpl<const N: usize> AsExpression<Nullable<Binary>> for [u8; N]
impl<const N: usize> AsExpression<Nullable<Binary>> for [u8; N]
type Expression = Bound<Nullable<Binary>, [u8; N]>
fn as_expression(self) -> <Self as AsExpression<Nullable<Binary>>>::Expression
Implementors
Sourceimpl AsExpression<Nullable<Timestamptz>> for now
Available on crate feature sqlite only.
impl AsExpression<Nullable<Timestamptz>> for now
Available on crate feature
sqlite only.type Expression = Coerce<now, Nullable<Timestamptz>>
Sourceimpl AsExpression<Timestamptz> for now
Available on crate feature sqlite only.
impl AsExpression<Timestamptz> for now
Available on crate feature
sqlite only.